# assaypy 🧑‍🔬🧪🧫

## summary

This python package helps analyzing high throughput assay data.

## how

Automating workflows and data handling of xlsx-files from TECAN. It returns plots and fitting data for multiple datasheets all analyzed in one go. More explanation [here](https://gnzng.github.io/assaypy/).
